@@ -75,6 +75,11 @@ data = {
                         "action": "store_true",
                         "help": "sign off the commit",
                     },
+                    {
+                        "name": ["-a", "--all"],
+                        "action": "store_true",
+                        "help": "Tell the command to automatically stage files that have been modified and deleted, but new files you have not told Git about are not affected.",
+                    },
                 ],
             },
             {
